@@ -1,4 +1,6 @@
 import csv
+import random
+import string
 from io import StringIO
 
 import yaml
@@ -42,6 +44,14 @@ class HyperfoilFactory:
         self._files[file_name] = (file_name, stream)
         return self
 
+    def generate_random_file(self, filename: str, size: int) -> 'HyperfoilFactory':
+        file = StringIO()
+        payload = ''.join([random.choice(string.ascii_letters) for _ in range(size)])
+        file.write(payload)
+        file.seek(0)
+        self.file(filename, file)
+        return self
+
     def csv_data(self, file_name: str, rows: [[str]], **kwargs) -> 'HyperfoilFactory':
         file = StringIO()
         csv_writer = csv.writer(file, delimiter=',', quotechar='"', quoting=csv.QUOTE_ALL, **kwargs)
